summaryrefslogtreecommitdiff
path: root/src/api/cvc4cppkind.h
diff options
context:
space:
mode:
authorAina Niemetz <aina.niemetz@gmail.com>2021-03-31 15:23:17 -0700
committerGitHub <noreply@github.com>2021-03-31 22:23:17 +0000
commita1466978fbc328507406d4a121dab4d1a1047e1d (patch)
tree12b40f161bb4d7a6ee40c20c78a15d6cda3c1995 /src/api/cvc4cppkind.h
parentf9a9af855fb65804ff0b36e764ccd9d0fa9f87f8 (diff)
Rename namespace CVC4 to CVC5. (#6249)
Diffstat (limited to 'src/api/cvc4cppkind.h')
-rw-r--r--src/api/cvc4cppkind.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/api/cvc4cppkind.h b/src/api/cvc4cppkind.h
index c98667da7..ef2f6af74 100644
--- a/src/api/cvc4cppkind.h
+++ b/src/api/cvc4cppkind.h
@@ -21,7 +21,7 @@
#include <ostream>
-namespace CVC4 {
+namespace CVC5 {
namespace api {
/* -------------------------------------------------------------------------- */
@@ -33,7 +33,7 @@ namespace api {
*
* Note that the underlying type of Kind must be signed (to enable range
* checks for validity). The size of this type depends on the size of
* CVC4::Kind (NodeValue::NBITS_KIND, currently 10 bits, see expr/node_value.h).
*/
enum CVC4_EXPORT Kind : int32_t
{
@@ -2868,6 +2868,6 @@ struct CVC4_EXPORT KindHashFunction
};
} // namespace api
-} // namespace CVC4
+} // namespace CVC5
#endif
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -33,7 +33,7 @@ namespace api {
* Note that the underlying type of Kind must be signed (to enable range
* checks for validity). The size of this type depends on the size of
- * CVC4::Kind (NodeValue::NBITS_KIND, currently 10 bits, see expr/node_value.h).
+ * CVC5::Kind (NodeValue::NBITS_KIND, currently 10 bits, see expr/node_value.h).
*/
enum CVC4_EXPORT Kind : int32_t